fix: fix for test test_contact_search_in_foreign_language
diff --git a/erpnext/tests/test_search.py b/erpnext/tests/test_search.py
index ab8eca3..8a93b6a 100644
--- a/erpnext/tests/test_search.py
+++ b/erpnext/tests/test_search.py
@@ -4,12 +4,12 @@
 from frappe.contacts.address_and_contact import filter_dynamic_link_doctypes
 
 class TestSearch(unittest.TestCase):
 	#Search for the word "clie", part of the word "client" (customer) in french.
 	def test_contact_search_in_foreign_language(self):
 		frappe.local.lang = 'fr'
-		output = filter_dynamic_link_doctypes("DocType", "clie", "name", 0, 20, {'fieldtype': 'HTML', 'fieldname': 'contact_html'})
+		output = filter_dynamic_link_doctypes("DocType", "cond", "name", 0, 20, {'fieldtype': 'HTML', 'fieldname': 'contact_html'})
 
-		result = [['found' for x in y if x=="Customer"] for y in output]
+		result = [['found' for x in y if x=="Lead"] for y in output]
 		self.assertTrue(['found'] in result)
 
 	def tearDown(self):
@@ -4,12 +4,12 @@
 
 class TestSearch(unittest.TestCase):
-	#Search for the word "clie", part of the word "client" (customer) in french.
+	#Search for the word "cond", part of the word "conduire" (Lead) in french.
 	def test_contact_search_in_foreign_language(self):
 		frappe.local.lang = 'fr'